# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['quart_cors']

package_data = \
{'': ['*']}

install_requires = \
['quart>=0.15']

extras_require = \
{':python_version < "3.10"': ['typing_extensions']}

setup_kwargs = {
    'name': 'quart-cors',
    'version': '0.6.0',
    'description': 'A Quart extension to provide Cross Origin Resource Sharing, access control, support',
    'long_description': 'Quart-CORS\n==========\n\n|Build Status| |pypi| |python| |license|\n\nQuart-CORS is an extension for `Quart\n<https://github.com/pgjones/quart>`_ to enable and control `Cross\nOrigin Resource Sharing <http://www.w3.org/TR/cors/>`_, CORS (also\nknown as access control).\n\nCORS is required to share resources in browsers due to the `Same\nOrigin Policy <https://en.wikipedia.org/wiki/Same-origin_policy>`_\nwhich prevents resources being used from a different origin. An origin\nin this case is defined as the scheme, host and port combined and a\nresource corresponds to a path.\n\nIn practice the Same Origin Policy means that a browser visiting\n``http://quart.com`` will prevent the response of ``GET\nhttp://api.com`` being read. It will also prevent requests such as\n``POST http://api.com``. Note that CORS applies to browser initiated\nrequests, non-browser clients such as ``requests`` are not subject to\nCORS restrictions.\n\nCORS allows a server to indicate to a browser that certain resources\ncan be used, contrary to the Same Origin Policy. It does so via\naccess-control headers that inform the browser how the resource can be\nused. For GET requests these headers are sent in the response. For\nnon-GET requests the browser must ask the server for the\naccess-control headers before sending the actual request, it does so\nvia a preflight OPTIONS request.\n\nThe Same Origin Policy does not apply to WebSockets, and hence there\nis no need for CORS. Instead the server alone is responsible for\ndeciding if the WebSocket is allowed and it should do so by inspecting\nthe WebSocket-request origin header.\n\nSimple (GET) requests should return CORS headers specifying the\norigins that are allowed to use the resource (response). This can be\nany origin, ``*`` (wildcard), or a list of specific origins. The\nresponse should also include a CORS header specifying whether\nresponse-credentials e.g. cookies can be used. Note that if credential\nsharing is allowed the allowed origins must be specific and not a\nwildcard.\n\nPreflight requests should return CORS headers specifying the origins\nallowed to use the resource, the methods and headers allowed to be\nsent in a request to the resource, whether response credentials can be\nused, and finally which response headers can be used.\n\nNote that certain actions are allowed in the Same Origin Policy such\nas embedding e.g. ``<img src="http://api.com/img.gif">`` and simple\nPOSTs. For the purposes of this readme though these complications are\nignored.\n\nThe CORS access control response headers are,\n\n================================ ===========================================================\nHeader name                      Meaning\n-------------------------------- -----------------------------------------------------------\nAccess-Control-Allow-Origin      Origins that are allowed to use the resource.\nAccess-Control-Allow-Credentials Can credentials be shared.\nAccess-Control-Allow-Methods     Methods that may be used in requests to the resource.\nAccess-Control-Allow-Headers     Headers that may be sent in requests to the resource.\nAccess-Control-Expose-Headers    Headers that may be read in the response from the resource.\nAccess-Control-Max-Age           Maximum age to cache the CORS headers for the resource.\n================================ ===========================================================\n\nQuart-CORS uses the same naming (without the Access-Control prefix)\nfor it\'s arguments and settings when they relate to the same meaning.\n\nUsage\n-----\n\nTo add CORS access control headers to all of the routes in the\napplication, simply apply the ``cors`` function to the application, or\nto a specific blueprint,\n\n.. code-block:: python\n\n    app = Quart(__name__)\n    app = cors(app, **settings)\n\n    blueprint = Blueprint(__name__)\n    blueprint = cors(blueprint, **settings)\n\nalternatively if you wish to add CORS selectively by resource, apply\nthe ``route_cors`` function to a route, or the ``websocket_cors``\nfunction to a WebSocket,\n\n.. code-block:: python\n\n    @app.route(\'/\')\n    @route_cors(**settings)\n    async def handler():\n        ...\n\n    @app.websocket(\'/\')\n    @websocket_cors(allow_origin=...)\n    async def handler():\n        ...\n\nThe ``settings`` are these arguments,\n\n================= ====================================================\nArgument          type\n----------------- ----------------------------------------------------\nallow_origin      Union[Set[Union[Pattern, str]], Union[Pattern, str]]\nallow_credentials bool\nallow_methods     Union[Set[str], str]\nallow_headers     Union[Set[str], str]\nexpose_headers    Union[Set[str], str]\nmax_age           Union[int, flot, timedelta]\n================= ====================================================\n\nwhich correspond to the CORS headers noted above. Note that all\nsettings are optional and defaults can be specified in the application\nconfiguration,\n\n============================ ========================\nConfiguration key            type\n---------------------------- ------------------------\nQUART_CORS_ALLOW_ORIGIN      Set[Union[Pattern, str]]\nQUART_CORS_ALLOW_CREDENTIALS bool\nQUART_CORS_ALLOW_METHODS     Set[str]\nQUART_CORS_ALLOW_HEADERS     Set[str]\nQUART_CORS_EXPOSE_HEADERS    Set[str]\nQUART_CORS_MAX_AGE           float\n============================ ========================\n\nThe ``websocket_cors`` decorator only takes an ``allow_origin``\nargument which defines the origins that are allowed to use the\nWebSocket. A WebSocket request from a disallowed origin will be\nresponded to with a 400 response.\n\nThe ``allow_origin`` origins should be the origin only (no path, query\nstrings or fragments) i.e. ``https://quart.com`` not\n``https://quart.com/``.\n\nThe ``cors_exempt`` decorator can be used in conjunction with ``cors``\nto exempt a websocket handler or view function from cors.\n\nSimple examples\n~~~~~~~~~~~~~~~\n\nTo allow an app to be used from any origin (not recommended as it is\ntoo permissive),\n\n.. code-block:: python\n\n    app = Quart(__name__)\n    app = cors(app, allow_origin="*")\n\nTo allow a route or WebSocket to be used from another specific domain,\n``https://quart.com``,\n\n.. code-block:: python\n\n    @app.route(\'/\')\n    @route_cors(allow_origin="https://quart.com")\n    async def handler():\n        ...\n\n    @app.websocket(\'/\')\n    @websocket_cors(allow_origin="https://quart.com")\n    async def handler():\n        ...\n\nTo allow a route or WebSocket to be used from any subdomain (but not\nthe domain itself) of ``quart.com``,\n\n.. code-block:: python\n\n    @app.route(\'/\')\n    @route_cors(allow_origin=re.compile(r"https:\\/\\/.*\\.quart\\.com"))\n    async def handler():\n        ...\n\n    @app.websocket(\'/\')\n    @websocket_cors(allow_origin=re.compile(r"https:\\/\\/.*\\.quart\\.com"))\n    async def handler():\n        ...\n\nTo allow a JSON POST request to an API route, from ``https://quart.com``,\n\n.. code-block:: python\n\n    @app.route(\'/\', methods=["POST"])\n    @route_cors(\n        allow_headers=["content-type"],\n        allow_methods=["POST"],\n        allow_origin=["https://quart.com"],\n    )\n    async def handler():\n        data = await request.get_json()\n        ...\n\nContributing\n------------\n\nQuart-CORS is developed on `GitHub\n<https://github.com/pgjones/quart-cors>`_. You are very welcome to\nopen `issues <https://github.com/pgjones/quart-cors/issues>`_ or\npropose `merge requests\n<https://github.com/pgjones/quart-cors/merge_requests>`_.\n\nTesting\n~~~~~~~\n\nThe best way to test Quart-CORS is with Tox,\n\n.. code-block:: console\n\n    $ pip install tox\n    $ tox\n\nthis will check the code style and run the tests.\n\nHelp\n----\n\nThis README is the best place to start, after that try opening an\n`issue <https://github.com/pgjones/quart-cors/issues>`_.\n\n\n.. |Build Status| image:: https://github.com/pgjones/quart-cors/actions/workflows/ci.yml/badge.svg\n   :target: https://github.com/pgjones/quart-cors/commits/main\n\n.. |pypi| image:: https://img.shields.io/pypi/v/quart-cors.svg\n   :target: https://pypi.python.org/pypi/Quart-CORS/\n\n.. |python| image:: https://img.shields.io/pypi/pyversions/quart-cors.svg\n   :target: https://pypi.python.org/pypi/Quart-CORS/\n\n.. |license| image:: https://img.shields.io/badge/license-MIT-blue.svg\n   :target: https://github.com/pgjones/quart-cors/blob/main/LICENSE\n',
    'author': 'pgjones',
    'author_email': 'philip.graham.jones@googlemail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/pgjones/quart-cors/',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.7',
}


setup(**setup_kwargs)
